==> haskell-cabal-install-solver-3.8.1.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-solver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-solver
version:              3.8.1.0
visibility:           public
id:                   cabal-install-solver-3.8.1.0-KKjZmQ3bQ7jCo8T6PWlq6R
key:                  cabal-install-solver-3.8.1.0-KKjZmQ3bQ7jCo8T6PWlq6R
license:              BSD-3-Clause
copyright:            2003-2022, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The solver component used in cabal-install command-line program

category:             Distribution
abi:                  7871dc7a3265524a8dddc0743c506954
exposed:              True
exposed-modules:
    Distribution.Client.Utils.Assertion
    Distribution.Solver.Compat.Prelude Distribution.Solver.Modular
    Distribution.Solver.Modular.Assignment
    Distribution.Solver.Modular.Builder
    Distribution.Solver.Modular.Configured
    Distribution.Solver.Modular.ConfiguredConversion
    Distribution.Solver.Modular.ConflictSet
    Distribution.Solver.Modular.Cycles
    Distribution.Solver.Modular.Dependency
    Distribution.Solver.Modular.Explore
    Distribution.Solver.Modular.Flag Distribution.Solver.Modular.Index
    Distribution.Solver.Modular.IndexConversion
    Distribution.Solver.Modular.LabeledGraph
    Distribution.Solver.Modular.Linking Distribution.Solver.Modular.Log
    Distribution.Solver.Modular.Message
    Distribution.Solver.Modular.MessageUtils
    Distribution.Solver.Modular.PSQ Distribution.Solver.Modular.Package
    Distribution.Solver.Modular.Preference
    Distribution.Solver.Modular.RetryLog
    Distribution.Solver.Modular.Solver Distribution.Solver.Modular.Tree
    Distribution.Solver.Modular.Validate
    Distribution.Solver.Modular.Var Distribution.Solver.Modular.Version
    Distribution.Solver.Modular.WeightedPSQ
    Distribution.Solver.Types.ComponentDeps
    Distribution.Solver.Types.ConstraintSource
    Distribution.Solver.Types.DependencyResolver
    Distribution.Solver.Types.Flag
    Distribution.Solver.Types.InstSolverPackage
    Distribution.Solver.Types.InstalledPreference
    Distribution.Solver.Types.LabeledPackageConstraint
    Distribution.Solver.Types.OptionalStanza
    Distribution.Solver.Types.PackageConstraint
    Distribution.Solver.Types.PackageFixedDeps
    Distribution.Solver.Types.PackageIndex
    Distribution.Solver.Types.PackagePath
    Distribution.Solver.Types.PackagePreferences
    Distribution.Solver.Types.PkgConfigDb
    Distribution.Solver.Types.Progress
    Distribution.Solver.Types.ResolverPackage
    Distribution.Solver.Types.Settings
    Distribution.Solver.Types.SolverId
    Distribution.Solver.Types.SolverPackage
    Distribution.Solver.Types.SourcePackage
    Distribution.Solver.Types.Variable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-solver
hs-libraries:         HScabal-install-solver-3.8.1.0-KKjZmQ3bQ7jCo8T6PWlq6R
depends:
    Cabal-3.8.1.0 Cabal-syntax-3.8.1.0 array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    edit-distance-0.2.2.1-6sTIi6n5TR7yFdbwrUT16 filepath-1.4.2.2
    mtl-2.2.2 pretty-1.1.3.6 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-solver/html/cabal-install-solver.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-solver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-install-solver-3.8.1.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-solver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-solver
version:              3.8.1.0
visibility:           public
id:                   cabal-install-solver-3.8.1.0-L7M3QbHMI00HbzSCLwC4Ac
key:                  cabal-install-solver-3.8.1.0-L7M3QbHMI00HbzSCLwC4Ac
license:              BSD-3-Clause
copyright:            2003-2022, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The solver component used in cabal-install command-line program

category:             Distribution
abi:                  9a78d06ee9bb51bb297778ce1cc5bd86
exposed:              True
exposed-modules:
    Distribution.Client.Utils.Assertion
    Distribution.Solver.Compat.Prelude Distribution.Solver.Modular
    Distribution.Solver.Modular.Assignment
    Distribution.Solver.Modular.Builder
    Distribution.Solver.Modular.Configured
    Distribution.Solver.Modular.ConfiguredConversion
    Distribution.Solver.Modular.ConflictSet
    Distribution.Solver.Modular.Cycles
    Distribution.Solver.Modular.Dependency
    Distribution.Solver.Modular.Explore
    Distribution.Solver.Modular.Flag Distribution.Solver.Modular.Index
    Distribution.Solver.Modular.IndexConversion
    Distribution.Solver.Modular.LabeledGraph
    Distribution.Solver.Modular.Linking Distribution.Solver.Modular.Log
    Distribution.Solver.Modular.Message
    Distribution.Solver.Modular.MessageUtils
    Distribution.Solver.Modular.PSQ Distribution.Solver.Modular.Package
    Distribution.Solver.Modular.Preference
    Distribution.Solver.Modular.RetryLog
    Distribution.Solver.Modular.Solver Distribution.Solver.Modular.Tree
    Distribution.Solver.Modular.Validate
    Distribution.Solver.Modular.Var Distribution.Solver.Modular.Version
    Distribution.Solver.Modular.WeightedPSQ
    Distribution.Solver.Types.ComponentDeps
    Distribution.Solver.Types.ConstraintSource
    Distribution.Solver.Types.DependencyResolver
    Distribution.Solver.Types.Flag
    Distribution.Solver.Types.InstSolverPackage
    Distribution.Solver.Types.InstalledPreference
    Distribution.Solver.Types.LabeledPackageConstraint
    Distribution.Solver.Types.OptionalStanza
    Distribution.Solver.Types.PackageConstraint
    Distribution.Solver.Types.PackageFixedDeps
    Distribution.Solver.Types.PackageIndex
    Distribution.Solver.Types.PackagePath
    Distribution.Solver.Types.PackagePreferences
    Distribution.Solver.Types.PkgConfigDb
    Distribution.Solver.Types.Progress
    Distribution.Solver.Types.ResolverPackage
    Distribution.Solver.Types.Settings
    Distribution.Solver.Types.SolverId
    Distribution.Solver.Types.SolverPackage
    Distribution.Solver.Types.SourcePackage
    Distribution.Solver.Types.Variable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-solver
hs-libraries:         HScabal-install-solver-3.8.1.0-L7M3QbHMI00HbzSCLwC4Ac
depends:
    Cabal-3.8.1.0 Cabal-syntax-3.8.1.0 array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    edit-distance-0.2.2.1-3JkpBtwlj9xCsT4o6b4IHR filepath-1.4.2.2
    mtl-2.2.2 pretty-1.1.3.6 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-solver/html/cabal-install-solver.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-solver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
